audformat.utils
===============

.. automodule:: audformat.utils


concat
------

.. autofunction:: concat


map_language
------------

.. autofunction:: map_language

read_csv
--------

.. autofunction:: read_csv

to_filewise_index
-----------------

.. autofunction:: to_filewise_index

to_segmented_index
------------------

.. autofunction:: to_segmented_index
